---
title: Redirecting…
---

<meta http-equiv="refresh" content="0; url=https://lancedb.com/docs/geneva/udfs/">
<link rel="canonical" href="url=https://lancedb.com/docs/geneva/udfs/">

If you are not redirected, <a href="url=https://lancedb.com/docs/geneva/udfs/">click here</a>.
